Index: trunk/psphot/src/psphotArguments.c
===================================================================
--- trunk/psphot/src/psphotArguments.c	(revision 4977)
+++ trunk/psphot/src/psphotArguments.c	(revision 5049)
@@ -22,9 +22,9 @@
   }
 
-  // optional noise image - add to config
-  char *noise = NULL;
-  if ((N = psArgumentGet (*argc, argv, "-noise"))) {
+  // optional weight image - add to config
+  char *weight = NULL;
+  if ((N = psArgumentGet (*argc, argv, "-weight"))) {
     psArgumentRemove (N, argc, argv);
-    noise = psStringCopy (argv[N]);
+    weight = psStringCopy (argv[N]);
     psArgumentRemove (N, argc, argv);
   }
@@ -46,5 +46,5 @@
   fprintf (stderr, "loaded config...\n");
 
   // identify input image & optional noise & mask images
   // command-line entries override config-file entries
   psMetadataAdd (config, PS_LIST_HEAD, "IMAGE",       mode, "", argv[1]);
@@ -54,6 +54,6 @@
     psMetadataAdd (config, PS_LIST_HEAD, "MASK_IMAGE", mode, "", mask);
   }
-  if (noise != NULL) {
-    psMetadataAdd (config, PS_LIST_HEAD, "NOISE_IMAGE", mode, "", noise);
+  if (weight != NULL) {
+    psMetadataAdd (config, PS_LIST_HEAD, "WEIGHT_IMAGE", mode, "", weight);
   }
   if (resid != NULL) {
@@ -68,5 +68,5 @@
     fprintf (stderr, "options: \n");
     fprintf (stderr, "  -mask  (filename)\n");
-    fprintf (stderr, "  -noise (filename)\n");
+    fprintf (stderr, "  -weight (filename)\n");
     fprintf (stderr, "  -resid (filename)\n");
     exit (2);
@@ -46,5 +46,5 @@
   fprintf (stderr, "loaded config...\n");
 
-  // identify input image & optional noise & mask images
+  // identify input image & optional weight & mask images
   // command-line entries override config-file entries
   psMetadataAdd (config, PS_LIST_HEAD, "IMAGE",       mode, "", argv[1]);
